==> ender-0.3.0.tgz: package/README.md <==
WELCOME TO YOU'RE "DOOM!"*
--------------------------

Ender is not a JavaScript library in the traditional sense. So don't rush out and try to replace jQuery or MooTools with Ender... It just wouldn't work.... But! **you can** build a library from Ender which will. And you should. right now.

That's because: *Ender is an open, powerful, micro-to-macro API for composing your own custom JavaScript library; it wraps up application agnostic, independent modules into a slick, intuitive, and familiar interface so you don't have to.*

Check it out:

![Ender](http://f.cl.ly/items/1W0P3I3D3m3U0e1j2h1c/Screen%20shot%202011-05-09%20at%2011.31.42%20AM.png)

OK, SURE... BUT WHY?
--------------------
Because in the browser - small, loosely coupled modules are the future, and large, tightly-bound monolithic libraries are the past!

Ponder this... Ender is unique and important in two key ways:

1) Ender provides front end developers with a true package management system and the powerful command line tools necessary to back it up... making your library maintenance tasks simple, painless, and fast.

2) Ender offers a way to bring together the awesome work happening in small frameworks and libraries that otherwise do only one thing, and allows you to mix, match, and customize your own library suited to your individual needs without all the extra cruft that comes with larger libraries.

GET STARTED NOW
---------------

Install [NodeJS](http://nodejs.org) and install [NPM](https://github.com/isaacs/npm). Then:

    npm install ender -g

then go to the directory you'd like to build a library in and run:

    ender -b some-microlib another-lib [etc...]

boosh. you have a library!

P.S.
---
that's correct, [you're doom!](http://blog.urbanbohemian.com/2009/04/08/5201/)

==> ender-0.3.4.tgz: package/README.md <==
WELCOME TO YOU'RE "DOOM!"*
--------------------------

Ender is not a JavaScript library in the traditional sense. So don't rush out and try to replace jQuery or MooTools with Ender... It just wouldn't work.... But! **you can** build a library from Ender which will. And you should. right now.

That's because: *Ender is an open, powerful, micro-to-macro API for composing your own custom JavaScript library; it wraps up application agnostic, independent modules into a slick, intuitive, and familiar interface so you don't have to.*

Check it out:

![Ender](http://f.cl.ly/items/1W0P3I3D3m3U0e1j2h1c/Screen%20shot%202011-05-09%20at%2011.31.42%20AM.png)

OK, SURE... BUT WHY?
--------------------
Because in the browser - small, loosely coupled modules are the future, and large, tightly-bound monolithic libraries are the past!

Ponder this... Ender is unique and important in two key ways:

1) Ender provides front end developers with a true package management system and the powerful command line tools necessary to back it up... making your library maintenance tasks simple, painless, and fast.

2) Ender offers a way to bring together the awesome work happening in small frameworks and libraries that otherwise do only one thing, and allows you to mix, match, and customize your own library suited to your individual needs without all the extra cruft that comes with larger libraries.

GET STARTED NOW
---------------

Install [NodeJS](http://nodejs.org) ( >= v0.4.0) and install [NPM](https://github.com/isaacs/npm) ( >= v1.0.0). Then install ender globally with the command:

    npm install ender -g

then go to the directory you'd like to build a library in and run:

    ender -b some-microlib another-lib [etc...]

boosh. you have a library!

HELP & SUPPORT
----------
For development questions, issues, bugs, ideas, suggestions -- join the Ender community and send us your thoughts at [enderjs.com](http://enderjs.com)

P.S.
---
that's correct, [you're doom!](http://blog.urbanbohemian.com/2009/04/08/5201/)
